diff --git a/chrome/content/zotero/integrationDocPrefs.xul b/chrome/content/zotero/integrationDocPrefs.xul
index 99e4d9f19f..d4af7bc622 100644
--- a/chrome/content/zotero/integrationDocPrefs.xul
+++ b/chrome/content/zotero/integrationDocPrefs.xul
@@ -39,7 +39,7 @@
-
+ &zotero.integration.prefs.bookmarks.caption;
diff --git a/chrome/locale/en-US/zotero/zotero.dtd b/chrome/locale/en-US/zotero/zotero.dtd
index 56405135e2..55c542c0e3 100644
--- a/chrome/locale/en-US/zotero/zotero.dtd
+++ b/chrome/locale/en-US/zotero/zotero.dtd
@@ -151,7 +151,7 @@
-
+
diff --git a/chrome/content/zotero/bibliography.js b/chrome/content/zotero/bibliography.js
index ad88123b2a..292ce38977 100644
--- a/chrome/content/zotero/bibliography.js
+++ b/chrome/content/zotero/bibliography.js
@@ -142,10 +142,14 @@ var Zotero_File_Interface_Bibliography = new function() {
var selectedStyle = selectedItem.getAttribute('value');
- // update status of displayAs box based
+ // update status of displayAs box based on style class
+ var isNote = Zotero.Styles.get(selectedStyle).class == "note";
+ document.getElementById("displayAs").disabled = !isNote;
- var styleClass = Zotero.Styles.get(selectedStyle).class;
- document.getElementById("displayAs").disabled = styleClass != "note";
+ // update status of formatUsing box based on style class
+ if(isNote) document.getElementById("formatUsing").selectedIndex = 0;
+ document.getElementById("bookmarks").disabled = isNote;
+ document.getElementById("bookmarks-caption").disabled = isNote;
}
function acceptSelection() {